//
// sls.cc for sls
//
// Made by Seblu
// Login   <seblu@epita.fr>
//
// Started on  Fri Jun  1 02:11:00 2007 Seblu
// Last update Thu Jun  7 02:54:58 2007 Seblu
//

#include "sls.hh"

int main(int argc, char *argv[])
{
  GetOption *getopt;
  Parser *parser;
  SLServer *server;

  // Check arg line count
  if (argc < GetOption::min_argc) {
    GetOption::usage(*argv);
    return EXIT_USAGE;
  }

  // Parse command line options
  try { getopt = new GetOption(argc, argv); }
  catch (const Error &e) {
    std::cerr << "ERROR: " << e.message() << std::endl;
    GetOption::usage(*argv);
    return EXIT_USAGE;
  }

  // Init server
  try { server = new SLServer(getopt->port()); }
  catch (const Error &e) {
    std::cerr << "ERROR: " << e.message() << std::endl;
    return e.code();
  }

  // Parse access database file
  try { parser = new Parser(getopt->accessfile(), *server, getopt->verbose()); }
  catch (const Error &e) {
    std::cerr << "ERROR: " << e.message() << std::endl;
    return e.code();
  }

  // Free parser and getopter
  delete getopt;
  delete parser;

  server->print_access();

  // Run server
  return server->run();
}
